package com.example.base;

import com.example.enums.ResultEnum;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 服务调用统一返回封装类
 *
 * @param <T>
 * @author yys
 */
@Data
@ApiModel(value = "client响应类", description = "client响应类")
public class ResultVO<T> {

    private static final Integer DEFAULT_COUNT = 0;
    /**
     * 状态码 （默认值:0）
     */
    @ApiModelProperty(value = "响应码", example = "响应码")
    private Integer code = ResultEnum.SUCCESS.getCode();
    /**
     * 状态提示信息 （默认值:成功）
     */
    @ApiModelProperty(value = "返回信息", example = "返回信息")
    private String msg = ResultEnum.SUCCESS.getMsg();

    /**
     * 记录总数，默认是0
     */
    private long count = DEFAULT_COUNT;
    /**
     * 业务数据
     */
    @ApiModelProperty(value = "返回内容", example = "返回内容")
    private T data;

    public ResultVO() {
        super();
    }

    public ResultVO(Integer code, String msg) {
        super();
        this.code = code;
        this.msg = msg;
    }

    public ResultVO(Integer code, String msg, T data) {
        super();
        this.code = code;
        this.msg = msg;
        this.data = data;
    }

    public ResultVO(Integer code, String msg, long count, T data) {
        super();
        this.code = code;
        this.msg = msg;
        this.count = count;
        this.data = data;
    }

    public ResultVO(ResultEnum resultEnum) {
        super();
        this.code = resultEnum.getCode();
        this.msg = resultEnum.getMsg();
    }

    public ResultVO(ResultEnum resultEnum, T data, long count) {
        super();
        this.code = resultEnum.getCode();
        this.msg = resultEnum.getMsg();
        this.data = data;
        this.count = count;
    }

    public ResultVO(ResultEnum resultEnum, T data) {
        super();
        this.code = resultEnum.getCode();
        this.msg = resultEnum.getMsg();
        this.data = data;
        this.count = count;
    }

}
