package com.example.util;

import com.example.base.Token;
import com.example.constant.GlobleConstant;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;

import javax.crypto.spec.SecretKeySpec;
import javax.xml.bind.DatatypeConverter;
import java.security.Key;
import java.sql.Timestamp;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * Token 生成工具类
 *
 * @author yys
 */
public class TokenUtil {

    /**
     * 签名秘钥
     */
    public static final String SECRET = "networkSecurity";
    /**
     * 签发者
     */
    public static final String ISSUER = "www.hywan.com";

    /**
     * 生成token
     *
     * @param id      用户Id
     * @param subject 用户类型
     * @author yys
     */
    public static Token createJwtToken(String id, String subject) {
        // 生成签发时间
        long nowMillis = System.currentTimeMillis();
        Date issueDate = new Date(nowMillis);
        Date tokenExpireDate = new Date(nowMillis + GlobleConstant.TOKEN_EXPIRES_SECOND * 1000);
        Date refreshtokenExpireDate = new Date(
                nowMillis + GlobleConstant.REFRESH_TOKEN_EXPIRES_SECOND * 1000);
        String accessToken = createJwtToken(id, ISSUER, subject, issueDate, tokenExpireDate,
                GlobleConstant.TOKEN_AUD);
        String refreshToken = createJwtToken(id, ISSUER, subject, issueDate, refreshtokenExpireDate,
                GlobleConstant.REFRESH_TOKEN_AUD);
        Token token = new Token();
        token.setExpireTime(new Timestamp(tokenExpireDate.getTime()));
        token.setAccessToken(accessToken);
        token.setRefreshToken(refreshToken);
        return token;
    }

    /**
     * 生成token
     *
     * @author yys
     */
    public static String createJwtToken(String id, String issuer, String subject, Date issueDate,
                                        Date expireDate, String aud) {

        // 签名算法 ，将对token进行签名
        SignatureAlgorithm signatureAlgorithm = SignatureAlgorithm.HS256;

        // 通过秘钥签名JWT
        byte[] apiKeySecretBytes = DatatypeConverter.parseBase64Binary(SECRET);
        Key signingKey = new SecretKeySpec(apiKeySecretBytes, signatureAlgorithm.getJcaName());
        Map<String, Object> claims = new HashMap<>();
        claims.put("uid", id);
        JwtBuilder builder = Jwts.builder().setClaims(claims).setId(id).setIssuedAt(issueDate)
                .setSubject(subject).setIssuer(issuer).setAudience(aud)
                .signWith(signatureAlgorithm, signingKey);
        builder.setExpiration(expireDate);
        return builder.compact();
    }

    /**
     * 解析验证token
     *
     * @author yys
     */
    public static Claims parseJWT(String token) {
        Claims claims = Jwts.parser().setSigningKey(DatatypeConverter.parseBase64Binary(SECRET))
                .parseClaimsJws(token)
                .getBody();
        return claims;
    }

    public static String getUserId(String token) {
        try {
            token = token.substring(0, token.length() - 32);
            Claims claims = Jwts.parser().setSigningKey(DatatypeConverter.parseBase64Binary(SECRET)).parseClaimsJws
                    (token)
                    .getBody();
            return claims.get("uid").toString();
        } catch (Exception e) {
            System.err.println("token 不合法===============>:" + token);
            return null;
        }
    }

//	public static void main(String[] args) {
//		Claims claims = TokenUtil.parseJWT
// ("eyJhbGciOiJIUzI1NiJ9.eyJqdGkiOiIyNzk2YjIzNmRiOGE0MjA5YTgyMGEzMTBiZmU1N2ZhNyIsImlhdCI6MTUzODM2Mzc2OSwic3ViIjoiQ3VycmVudE1lbWJlciIsImlzcyI6Ind3dy5oeXdhbi5jb20iLCJhdWQiOiJ0b2tlbkF1ZCIsImV4cCI6MTUzODk2ODU2OX0.Bd0FFqDyRcrjcWgUclo57N8TmR_rgZJ7-n6Amia7_0w");
//		System.out.printf(claims.getSubject());
//	}
}
